@@ -3,6 +3,8 @@ from loaderio.models import Validation
 
 
 class ValidationAdmin(admin.ModelAdmin):
-    fields = ['token']
+    fields = ['token', 'enabled']
+    list_display = ['token', 'enabled']
+    list_editable = ['enabled']
 
 admin.site.register(Validation, ValidationAdmin)
